@@ -56,6 +56,7 @@ module.exports = function (grunt) {
             format: 'iife',
             banner: '(function () {',
             footer: '})();',
+            onwarn: swag.onwarn,
             plugins: [
               swag.nodeResolve({
                 basedir: __dirname,
@@ -82,6 +83,7 @@ module.exports = function (grunt) {
             format: 'iife',
             banner: '(function () {',
             footer: '})();',
+            onwarn: swag.onwarn,
             plugins: [
               swag.nodeResolve({
                 basedir: __dirname,
@@ -89,7 +91,11 @@ module.exports = function (grunt) {
                   'tinymce/core': 'lib/globals/tinymce/core'
                 }, [
                   [`tinymce/plugins/${name}`, `lib/plugins/${name}/main/ts`]
-                ])
+                ]),
+                mappers: [
+                  swag.mappers.replaceDir('./lib/core/main/ts/api', './lib/globals/tinymce/core/api'),
+                  swag.mappers.invalidDir('./lib/core/main/ts')
+                ]
               }),
               swag.remapImports()
             ]
@@ -105,6 +111,7 @@ module.exports = function (grunt) {
             format: 'iife',
             banner: '(function () {',
             footer: '})();',
+            onwarn: swag.onwarn,
             plugins: [
               swag.nodeResolve({
                 basedir: __dirname,
@@ -113,7 +120,11 @@ module.exports = function (grunt) {
                   'tinymce/ui': 'lib/ui/main/ts'
                 }, [
                   [`tinymce/themes/${name}`, `lib/themes/${name}/main/ts`]
-                ])
+                ]),
+                mappers: [
+                  swag.mappers.replaceDir('./lib/core/main/ts/api', './lib/globals/tinymce/core/api'),
+                  swag.mappers.invalidDir('./lib/core/main/ts')
+                ]
               }),
               swag.remapImports()
             ]
@@ -725,6 +736,16 @@ module.exports = function (grunt) {
         customRoutes: 'src/core/test/json/routes.json',
         name: 'chrome-headless'
       },
+      'firefox-headless': {
+        browser: 'firefox-headless',
+        config: 'tsconfig.json',
+        testfiles: ['src/**/test/ts/**/*Test.ts'],
+        stopOnFailure: true,
+        overallTimeout: 600000,
+        singleTimeout: 300000,
+        customRoutes: 'src/core/test/json/routes.json',
+        name: 'firefox-headless'
+      },
       chrome: {
         browser: 'chrome',
         config: 'tsconfig.json',
@@ -790,12 +811,11 @@ module.exports = function (grunt) {
 
   require('load-grunt-tasks')(grunt);
   grunt.loadTasks('tools/tasks');
-  grunt.loadNpmTasks('@ephox/bedrock');
+  grunt.loadNpmTasks('@ephox/bedrock-server');
   grunt.loadNpmTasks('@ephox/swag');
   grunt.loadNpmTasks('grunt-tslint');
 
   grunt.registerTask('prod', [
-    'validateVersion',
     'shell:tsc',
     'tslint',
     'globals',
