@@ -1,11 +1,8 @@
 /**
- * Editor.js
- *
- * Released under LGPL License.
- * Copyright (c) 1999-2017 Ephox Corp. All rights reserved
- *
- * License: http://www.tinymce.com/license
- * Contributing: http://www.tinymce.com/contributing
+ * Copyright (c) Tiny Technologies, Inc. All rights reserved.
+ * Licensed under the LGPL or a commercial license.
+ * For LGPL see License.txt in the project root for license information.
+ * For commercial licenses see https://www.tiny.cloud/
  */
 
 import { AddOnManager } from './AddOnManager';
@@ -516,7 +513,6 @@ Editor.prototype = {
       settings.icon = name;
     }
 
-    self.buttons = self.buttons;
     settings.tooltip = settings.tooltip || settings.title;
     self.buttons[name] = settings;
   },
@@ -580,7 +576,6 @@ Editor.prototype = {
       };
     }
 
-    self.menuItems = self.menuItems;
     self.menuItems[name] = settings;
   },
 
