@@ -1,11 +1,8 @@
 /**
- * Events.js
- *
- * Released under LGPL License.
- * Copyright (c) 1999-2016 Ephox Corp. All rights reserved
- *
- * License: http://www.tinymce.com/license
- * Contributing: http://www.tinymce.com/contributing
+ * Copyright (c) Tiny Technologies, Inc. All rights reserved.
+ * Licensed under the LGPL or a commercial license.
+ * For LGPL see License.txt in the project root for license information.
+ * For commercial licenses see https://www.tiny.cloud/
  */
 
 import { Editor } from 'tinymce/core/api/Editor';
@@ -18,6 +15,8 @@ const firePostProcess = (editor: Editor, args) => editor.fire('PostProcess', arg
 
 const fireRemove = (editor: Editor) => editor.fire('remove');
 
+const fireDetach = (editor: Editor) => editor.fire('detach');
+
 const fireSwitchMode = (editor: Editor, mode: EditorMode) => editor.fire('SwitchMode', { mode });
 
 const fireObjectResizeStart = (editor: Editor, target: HTMLElement, width: number, height: number) => {
@@ -32,6 +31,7 @@ export default {
   firePreProcess,
   firePostProcess,
   fireRemove,
+  fireDetach,
   fireSwitchMode,
   fireObjectResizeStart,
   fireObjectResized
