@@ -1,11 +1,8 @@
 /**
- * ControlSelection.js
- *
- * Released under LGPL License.
- * Copyright (c) 1999-2017 Ephox Corp. All rights reserved
- *
- * License: http://www.tinymce.com/license
- * Contributing: http://www.tinymce.com/contributing
+ * Copyright (c) Tiny Technologies, Inc. All rights reserved.
+ * Licensed under the LGPL or a commercial license.
+ * For LGPL see License.txt in the project root for license information.
+ * For commercial licenses see https://www.tiny.cloud/
  */
 
 import { Element as SugarElement, Selectors } from '@ephox/sugar';
@@ -134,7 +131,6 @@ const ControlSelection = (selection: Selection, editor: Editor): ControlSelectio
     const target = evt.target;
 
     if (isEventOnImageOutsideRange(evt, editor.selection.getRng()) && !evt.isDefaultPrevented()) {
-      evt.preventDefault();
       editor.selection.select(target);
     }
   };
