@@ -1,11 +1,8 @@
 /**
- * DomParser.js
- *
- * Released under LGPL License.
- * Copyright (c) 1999-2017 Ephox Corp. All rights reserved
- *
- * License: http://www.tinymce.com/license
- * Contributing: http://www.tinymce.com/contributing
+ * Copyright (c) Tiny Technologies, Inc. All rights reserved.
+ * Licensed under the LGPL or a commercial license.
+ * For LGPL see License.txt in the project root for license information.
+ * For commercial licenses see https://www.tiny.cloud/
  */
 
 import LegacyFilter from '../../html/LegacyFilter';
@@ -178,6 +175,7 @@ export default function (settings?, schema = Schema()) {
   const filterNode = (node: Node): Node => {
     let i, name, list;
 
+    name = node.name;
     // Run element filters
     if (name in nodeFilters) {
       list = matchedNodes[name];
@@ -210,7 +208,7 @@ export default function (settings?, schema = Schema()) {
 
   /**
    * Adds a node filter function to the parser, the parser will collect the specified nodes by name
-   * and then execute the callback ones it has finished parsing the document.
+   * and then execute the callback once it has finished parsing the document.
    *
    * @example
    * parser.addNodeFilter('p,h1', function(nodes, name) {
@@ -248,7 +246,7 @@ export default function (settings?, schema = Schema()) {
 
   /**
    * Adds a attribute filter function to the parser, the parser will collect nodes that has the specified attributes
-   * and then execute the callback ones it has finished parsing the document.
+   * and then execute the callback once it has finished parsing the document.
    *
    * @example
    * parser.addAttributeFilter('src,href', function(nodes, name) {
@@ -709,4 +707,4 @@ export default function (settings?, schema = Schema()) {
   LegacyFilter.register(exports, settings);
 
   return exports;
-}
\ No newline at end of file
+}
