@@ -1,11 +1,8 @@
 /**
- * VK.js
- *
- * Released under LGPL License.
- * Copyright (c) 1999-2017 Ephox Corp. All rights reserved
- *
- * License: http://www.tinymce.com/license
- * Contributing: http://www.tinymce.com/contributing
+ * Copyright (c) Tiny Technologies, Inc. All rights reserved.
+ * Licensed under the LGPL or a commercial license.
+ * For LGPL see License.txt in the project root for license information.
+ * For commercial licenses see https://www.tiny.cloud/
  */
 
 import Env from '../Env';
@@ -25,6 +22,8 @@ export default {
   SPACEBAR: 32,
   TAB: 9,
   UP: 38,
+  END: 35,
+  HOME: 36,
 
   modifierPressed (e: KeyboardEvent): boolean {
     return e.shiftKey || e.ctrlKey || e.altKey || this.metaKeyPressed(e);
