@@ -1,22 +1,19 @@
 /**
- * BlockBoundaryDelete.js
- *
- * Released under LGPL License.
- * Copyright (c) 1999-2017 Ephox Corp. All rights reserved
- *
- * License: http://www.tinymce.com/license
- * Contributing: http://www.tinymce.com/contributing
+ * Copyright (c) Tiny Technologies, Inc. All rights reserved.
+ * Licensed under the LGPL or a commercial license.
+ * For LGPL see License.txt in the project root for license information.
+ * For commercial licenses see https://www.tiny.cloud/
  */
 
 import { Element } from '@ephox/sugar';
-import BlockBoundary from './BlockBoundary';
+import BlockMergeBoundary from './BlockMergeBoundary';
 import MergeBlocks from './MergeBlocks';
 
 const backspaceDelete = function (editor, forward) {
   let position;
   const rootNode = Element.fromDom(editor.getBody());
 
-  position = BlockBoundary.read(rootNode.dom(), forward, editor.selection.getRng()).bind(function (blockBoundary) {
+  position = BlockMergeBoundary.read(rootNode.dom(), forward, editor.selection.getRng()).bind(function (blockBoundary) {
     return MergeBlocks.mergeBlocks(rootNode, forward, blockBoundary.from().block(), blockBoundary.to().block());
   });
 
