@@ -1,11 +1,8 @@
 /**
- * RemoveFormat.js
- *
- * Released under LGPL License.
- * Copyright (c) 1999-2017 Ephox Corp. All rights reserved
- *
- * License: http://www.tinymce.com/license
- * Contributing: http://www.tinymce.com/contributing
+ * Copyright (c) Tiny Technologies, Inc. All rights reserved.
+ * Licensed under the LGPL or a commercial license.
+ * For LGPL see License.txt in the project root for license information.
+ * For commercial licenses see https://www.tiny.cloud/
  */
 
 import Bookmarks from '../bookmark/Bookmarks';
@@ -20,6 +17,11 @@ import Tools from '../api/util/Tools';
 import { Selection } from '../api/dom/Selection';
 import GetBookmark from 'tinymce/core/bookmark/GetBookmark';
 import { Editor } from 'tinymce/core/api/Editor';
+import SplitRange from 'tinymce/core/selection/SplitRange';
+import { Node } from '@ephox/dom-globals';
+import { DOMUtils } from 'tinymce/core/api/dom/DOMUtils';
+import { Element, Traverse, InsertAll, Insert } from '@ephox/sugar';
+import { Option } from '@ephox/katamari';
 
 const MCE_ATTR_RE = /^(src|href|style)$/;
 const each = Tools.each;
@@ -29,6 +31,10 @@ const isTableCell = function (node) {
   return /^(TH|TD)$/.test(node.nodeName);
 };
 
+const isChildOfInlineParent = (dom: DOMUtils, node: Node, parent: Node): boolean => {
+  return dom.isChildOf(node, parent) && node !== parent && !dom.isBlock(parent);
+};
+
 const getContainer = function (ed, rng, start?) {
   let container, offset, lastIdx;
 
@@ -67,6 +73,23 @@ const wrap = function (dom, node, name, attrs?) {
   return wrapper;
 };
 
+const wrapWithSiblings = (dom: DOMUtils, node: Node, next: boolean, name: string, attrs?): Node => {
+  const start = Element.fromDom(node);
+  const wrapper = Element.fromDom(dom.create(name, attrs));
+  const siblings = next ? Traverse.nextSiblings(start) : Traverse.prevSiblings(start);
+
+  InsertAll.append(wrapper, siblings);
+  if (next) {
+    Insert.before(start, wrapper);
+    Insert.prepend(wrapper, start);
+  } else {
+    Insert.after(start, wrapper);
+    Insert.append(wrapper, start);
+  }
+
+  return wrapper.dom();
+};
+
 /**
  * Checks if the specified nodes name matches the format inline/block or selector.
  *
@@ -361,6 +384,12 @@ const remove = function (ed: Editor, name: string, vars?, node?, similar?) {
     return wrapAndSplit(ed, formatList, formatRoot, container, container, true, format, vars);
   };
 
+  const isRemoveBookmarkNode = function (node: Node) {
+    // Make sure to only check for bookmarks created here (eg _start or _end)
+    // as there maybe nested bookmarks
+    return Bookmarks.isBookmarkNode(node) && NodeType.isElement(node) && (node.id === '_start' || node.id === '_end');
+  };
+
   // Merges the styles for each node
   const process = function (node) {
     let children, i, l, lastContentEditable, hasContentEditableState;
@@ -405,7 +434,7 @@ const remove = function (ed: Editor, name: string, vars?, node?, similar?) {
     // If the end is placed within the start the result will be removed
     // So this checks if the out node is a bookmark node if it is it
     // checks for another more suitable node
-    if (Bookmarks.isBookmarkNode(out)) {
+    if (isRemoveBookmarkNode(out)) {
       out = out[start ? 'firstChild' : 'lastChild'];
     }
 
@@ -426,6 +455,9 @@ const remove = function (ed: Editor, name: string, vars?, node?, similar?) {
     rng = ExpandRange.expandRng(ed, rng, formatList, true);
 
     if (format.split) {
+      // Split text nodes
+      rng = SplitRange.split(rng);
+
       startContainer = getContainer(ed, rng, true);
       endContainer = getContainer(ed, rng);
 
@@ -448,10 +480,19 @@ const remove = function (ed: Editor, name: string, vars?, node?, similar?) {
           endContainer = endContainer.firstChild || endContainer;
         }
 
-        if (dom.isChildOf(startContainer, endContainer) && startContainer !== endContainer && !dom.isBlock(endContainer) && !isTableCell(startContainer) && !isTableCell(endContainer)) {
-          startContainer = wrap(dom, startContainer, 'span', { 'id': '_start', 'data-mce-type': 'bookmark' });
-          splitToFormatRoot(startContainer);
-          startContainer = unwrap(true);
+        // Wrap and split if nested
+        if (isChildOfInlineParent(dom, startContainer, endContainer)) {
+          const marker = Option.from(startContainer.firstChild).getOr(startContainer);
+          splitToFormatRoot(wrapWithSiblings(dom, marker, true, 'span', { 'id': '_start', 'data-mce-type': 'bookmark' }));
+          unwrap(true);
+          return;
+        }
+
+        // Wrap and split if nested
+        if (isChildOfInlineParent(dom, endContainer, startContainer)) {
+          const marker = Option.from(endContainer.lastChild).getOr(endContainer);
+          splitToFormatRoot(wrapWithSiblings(dom, marker, false, 'span', { 'id': '_end', 'data-mce-type': 'bookmark' }));
+          unwrap(false);
           return;
         }
 
