@@ -1,11 +1,8 @@
 /**
- * EnterKey.js
- *
- * Released under LGPL License.
- * Copyright (c) 1999-2017 Ephox Corp. All rights reserved
- *
- * License: http://www.tinymce.com/license
- * Contributing: http://www.tinymce.com/contributing
+ * Copyright (c) Tiny Technologies, Inc. All rights reserved.
+ * Licensed under the LGPL or a commercial license.
+ * For LGPL see License.txt in the project root for license information.
+ * For commercial licenses see https://www.tiny.cloud/
  */
 
 import InsertNewLine from '../newline/InsertNewLine';
@@ -13,8 +10,9 @@ import VK from '../api/util/VK';
 import { Editor } from 'tinymce/core/api/Editor';
 import { EditorEvent } from 'tinymce/core/api/dom/EventUtils';
 import { KeyboardEvent } from '@ephox/dom-globals';
+import { UndoManager } from '../api/UndoManager';
 
-const endTypingLevel = function (undoManager) {
+const endTypingLevel = function (undoManager: UndoManager) {
   if (undoManager.typing) {
     undoManager.typing = false;
     undoManager.add();
