@@ -1,14 +1,11 @@
 /**
- * SpaceKey.js
- *
- * Released under LGPL License.
- * Copyright (c) 1999-2017 Ephox Corp. All rights reserved
- *
- * License: http://www.tinymce.com/license
- * Contributing: http://www.tinymce.com/contributing
+ * Copyright (c) Tiny Technologies, Inc. All rights reserved.
+ * Licensed under the LGPL or a commercial license.
+ * For LGPL see License.txt in the project root for license information.
+ * For commercial licenses see https://www.tiny.cloud/
  */
 
-import InsertSpace from './InsertSpace';
+import * as InsertSpace from './InsertSpace';
 import MatchKeys from './MatchKeys';
 import VK from '../api/util/VK';
 import { Editor } from 'tinymce/core/api/Editor';
@@ -17,7 +14,7 @@ import { KeyboardEvent } from '@ephox/dom-globals';
 
 const executeKeydownOverride = function (editor: Editor, evt: KeyboardEvent) {
   MatchKeys.execute([
-    { keyCode: VK.SPACEBAR, action: MatchKeys.action(InsertSpace.insertAtSelection, editor) }
+    { keyCode: VK.SPACEBAR, action: MatchKeys.action(InsertSpace.insertSpaceOrNbspAtSelection, editor) }
   ], evt).each(function (_) {
     evt.preventDefault();
   });
