@@ -1,11 +1,8 @@
 /**
- * Plugin.js
- *
- * Released under LGPL License.
- * Copyright (c) 1999-2017 Ephox Corp. All rights reserved
- *
- * License: http://www.tinymce.com/license
- * Contributing: http://www.tinymce.com/contributing
+ * Copyright (c) Tiny Technologies, Inc. All rights reserved.
+ * Licensed under the LGPL or a commercial license.
+ * For LGPL see License.txt in the project root for license information.
+ * For commercial licenses see https://www.tiny.cloud/
  */
 
 import { Cell } from '@ephox/katamari';
@@ -13,6 +10,7 @@ import PluginManager from 'tinymce/core/api/PluginManager';
 import Api from './api/Api';
 import Commands from './api/Commands';
 import Keyboard from './core/Keyboard';
+import Bindings from './core/Bindings';
 import * as Buttons from './ui/Buttons';
 
 PluginManager.add('visualchars', function (editor) {
@@ -21,6 +19,7 @@ PluginManager.add('visualchars', function (editor) {
   Commands.register(editor, toggleState);
   Buttons.register(editor);
   Keyboard.setup(editor, toggleState);
+  Bindings.setup(editor, toggleState);
 
   return Api.get(toggleState);
 });
