@@ -1,11 +1,8 @@
 /**
- * Conversions.js
- *
- * Released under LGPL License.
- * Copyright (c) 1999-2016 Ephox Corp. All rights reserved
- *
- * License: http://www.tinymce.com/license
- * Contributing: http://www.tinymce.com/contributing
+ * Copyright (c) Tiny Technologies, Inc. All rights reserved.
+ * Licensed under the LGPL or a commercial license.
+ * For LGPL see License.txt in the project root for license information.
+ * For commercial licenses see https://www.tiny.cloud/
  */
 
 import { FileReader } from '@ephox/sand';
@@ -14,7 +11,7 @@ import { Blob } from '@ephox/dom-globals';
 
 const blobToBase64 = function (blob: Blob) {
   return new Promise<string>(function (resolve) {
-    const reader = new FileReader();
+    const reader = FileReader();
 
     reader.onloadend = function () {
       resolve(reader.result.split(',')[1]);
